;**************************************************************************
;*
;* FILE  diskutil.asm
;* Written by Daniel Kahlin <daniel@kahlin.net>
;* $Id$
;*
;* DESCRIPTION
;*   Generic disk utility routines.
;*
;*
;* fastformat - a faster format for the Commodore 1541/1571 
;*
;* Copyright (c) 1995, 1996, 2002, Daniel Kahlin <daniel@kahlin.net>
;* All rights reserved.
;* 
;* Redistribution and use in source and binary forms, with or without
;* modification, are permitted provided that the following conditions
;* are met:
;* 1. Redistributions of source code must retain the above copyright
;*    notice, this list of conditions and the following disclaimer.
;* 2. Redistributions in binary form must reproduce the above copyright
;*    notice, this list of conditions and the following disclaimer in the
;*    documentation and/or other materials provided with the distribution.
;* 3. Neither the names of the copyright holders nor the names of their
;*    contributors may be used to endorse or promote products derived 
;*    from this software without specific prior written permission.
;* 
;* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
;* ``AS IS AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
;* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
;* A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR
;* CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
;* EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
;* PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
;* PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
;* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
;* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
;* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;*
;******


;**************************************************************************
;*
;* Get Dosmessage and print it.
;*
;******
GetStatus:

;*
;* initialize and open error channel
;*
	lda	#15
	tay
	ldx	$ba
	jsr	$ffba	;SETLFS
	lda	#0
	jsr	$ffbd	;SETNAM
	jsr	$ffc0	;OPEN
	ldx	#15
	jsr	$ffc6	;CHKIN
;*
;* get error string from drive
;*
	ldy	#0
gs_lp1:
	jsr	$ffcf	;CHRIN
	jsr	$ffd2	;CHROUT
	cmp	#13
	bne	gs_lp1

;*
;* exit, clean up
;*
	jsr	$ffcc	;CLRCH
	jsr	$ffe7	;CLALL
	rts



;**************************************************************************
;*
;* Send DiskCommand...
;*
;******
DiskCommand:

;*
;* initialize, open error channel and send command
;*
	lda	#15
	tay
	ldx	$ba
	jsr	$ffba	;SETLFS
	jsr	$ffc0	;OPEN

;*
;* exit, clean up
;*
	lda	#15
	jsr	$ffc3	;CLOSE
	rts

;**************************************************************************
;*
;* ShowDirectory...
;*
;******
ShowDirectory:

;*
;* initialize and open
;*
	lda	#DnamLen
	ldx	#<Dnam
	ldy	#>Dnam
	jsr	$ffbd	;SETNAM
	lda	#1
	ldx	$ba
	ldy	#$60
	jsr	$ffba	;SETLFS
	jsr	$ffc0	;OPEN
	lda	$ba
	jsr	$ffb4	;TALK
	lda	$b9
	jsr	$ff96	;TKSA

	ldy	#$03
sd_lp1:
	sty	sd_tmp
sd_lp2:
	jsr	$ffa5	;ACPTR
	sta	sd_linenum
	jsr	$ffa5	;ACPTR
	sta	sd_linenum+1
	ldy	$90
	bne	sd_ex1
	dec	sd_tmp
	bne	sd_lp2
	jsr	sd_outputdecimal
	lda	#" "
	jsr	$ffd2	;CHROUT
sd_lp3:
	jsr	$ffa5	;ACPTR
	ldx	$90
	bne	sd_ex1
	cmp	#0
	beq	sd_skp1
	jsr	$ffd2	;CHROUT
	jmp	sd_lp3
sd_skp1:
	lda	#13
	jsr	$ffd2	;CHROUT
	ldy	#$02
sd_lp4:
	jsr	$ffe1	;STOP
	bne	sd_lp1

sd_ex1:

;*
;* exit, clean up
;*
	jsr	$ffab	;UNTLK
	lda	#1
	jsr	$ffc3	;CLOSE
	jsr	$ffe7	;CLALL
	clc
	rts
;***
Dnam:
	dc.b	"$0"
DnamLen	EQU	.-Dnam

sd_linenum:
	dc.w	0
sd_tmp:
	dc.b	0

sd_outputdecimal:
	ldx	sd_linenum
	lda	sd_linenum+1
	IFCONST	C64
	jsr	$bdcd	;Output decimal number
	ENDIF
	IFCONST	VIC20
	jsr	$ddcd	;Output decimal number
	ENDIF
	rts

; eof
