;**************************************************************************
;*
;* FILE  runformat.asm
;* Written by Daniel Kahlin <daniel@kahlin.net>
;* $Id$
;*
;* DESCRIPTION
;*   User interface for the fast format routine.
;*
;* ASSEMBLING
;*   dasm runformat.asm -DC64 for c64 binary
;*   dasm runformat.asm -DVIC20 for vic20 binary (needs 8Kb or more)
;*
;*
;* fastformat - a faster format for the Commodore 1541/1571 
;*
;* Copyright (c) 1995, 1996, 2002, Daniel Kahlin <daniel@kahlin.net>
;* All rights reserved.
;* 
;* Redistribution and use in source and binary forms, with or without
;* modification, are permitted provided that the following conditions
;* are met:
;* 1. Redistributions of source code must retain the above copyright
;*    notice, this list of conditions and the following disclaimer.
;* 2. Redistributions in binary form must reproduce the above copyright
;*    notice, this list of conditions and the following disclaimer in the
;*    documentation and/or other materials provided with the distribution.
;* 3. Neither the names of the copyright holders nor the names of their
;*    contributors may be used to endorse or promote products derived 
;*    from this software without specific prior written permission.
;* 
;* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
;* ``AS IS AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
;* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
;* A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR
;* CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
;* EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
;* PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
;* PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
;* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
;* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
;* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;*
;******
	PROCESSOR 6502

	IFCONST	C64
	ORG	$0801
StartOfFile:
	dc.w	EndLine
	dc.w	2002
	dc.b	$9e,"2069 /T.L.R/",0
;	     2002 SYS2069 /T.L.R/
	ENDIF
	IFCONST	VIC20
	ORG	$1201
	dc.w	EndLine
	dc.w	2002
	dc.b	$9e,"4629 /T.L.R/",0
;	     2002 SYS4629 /T.L.R/
	ENDIF
EndLine:
	dc.w	0


;**************************************************************************
;*
;* The Startup
;*
;******
SysAddress:
;*** Show Startup Message ***
	lda	#<init_msg
	ldy	#>init_msg
	IFCONST	C64
	jsr	$ab1e
	ENDIF
	IFCONST	VIC20
	jsr	$cb1e
	ENDIF

	lda	#8
	sta	$ba	;set up device number

commandloop:
	lda	#<vfyon_msg
	ldy	#>vfyon_msg
	ldx	vfy_flag
	bne	cl_skp1
	lda	#<vfyoff_msg
	ldy	#>vfyoff_msg	
cl_skp1:
	IFCONST	C64
	jsr	$ab1e
	ENDIF
	IFCONST	VIC20
	jsr	$cb1e
	ENDIF

; print device number
	lda	$ba
	clc
	adc	#$30
	jsr	$ffd2	;CHROUT

	lda	#13
	jsr	$ffd2	;CHROUT

	lda	#<command_msg
	ldy	#>command_msg
	IFCONST	C64
	jsr	$ab1e
	ENDIF
	IFCONST	VIC20
	jsr	$cb1e
	ENDIF


;* get string, and call SETNAM
	ldx	#0
sa_lp1:
	jsr	$ffcf	;CHRIN
	sta	namebuf,x
	cmp	#13
	beq	sa_ex1
	inx
	cpx	#namebuflen
	bne	sa_lp1
sa_ex1:
	txa
	ldx	#<namebuf
	ldy	#>namebuf
	jsr	$ffbd	;SETNAM

	lda	#13
	jsr	$ffd2	;CHROUT
	jsr	$ffd2	;CHROUT

; check for command
	lda	namebuf
	cmp	#13
	beq	sa_continue
	cmp	#"N"
	beq	sa_turboformat
	cmp	#"$"
	beq	sa_directory
	cmp	#"Q"
	beq	sa_exit
	cmp	#"Y"
	beq	sa_togglevfy

; no special command, just do a normal disk command
sa_diskcommand:
	lda	#<normal_msg
	ldy	#>normal_msg
	IFCONST	C64
	jsr	$ab1e
	ENDIF
	IFCONST	VIC20
	jsr	$cb1e
	ENDIF
	jsr	DiskCommand
	lda	#13
	jsr	$ffd2	;CHROUT
	jmp	sa_continue

sa_togglevfy:
	lda	vfy_flag
	eor	#$ff
	sta	vfy_flag
	jmp	commandloop

sa_directory:
	jsr	ShowDirectory
	jmp	sa_continue

sa_turboformat:
	lda	#<fast_msg
	ldy	#>fast_msg
	IFCONST	C64
	jsr	$ab1e
	ENDIF
	IFCONST	VIC20
	jsr	$cb1e
	ENDIF
	jsr	TurboFormat
	lda	#13
	jsr	$ffd2	;CHROUT

sa_continue:
; dump drive status and loop
	jsr	GetStatus
	jmp	commandloop

sa_exit:
	lda	#<exit_msg
	ldy	#>exit_msg
	IFCONST	C64
	jsr	$ab1e
	ENDIF
	IFCONST	VIC20
	jsr	$cb1e
	ENDIF

;*** Exit to basic ***
	IFCONST	C64
	jmp	$a474	;Exit to BASIC DIRECTMODE
	ENDIF
	IFCONST	VIC20
	jmp	$c474	;Exit to BASIC DIRECTMODE
	ENDIF


;**************************************************************************
;*
;* data
;*
;******
init_msg:
	dc.b	13
	dc.b	"*1541/71 FASTFORMAT*",13
	dc.b	"24 SECS WITH VERIFY",13
	dc.b	"(C) 1995,1996,2002",13
	dc.b    "DANIEL KAHLIN",13
	dc.b	0
vfyon_msg:
	dc.b	13,"VERIFY ON, DEVICE ",0
vfyoff_msg:
	dc.b	13,"VERIFY OFF, DEVICE ",0
command_msg:
	dc.b	"($=DIR, <CR>=STATUS,",13
	dc.b	"Q=QUIT, Y=TOGGLE VFY)",13
	dc.b	"COMMAND: "
	dc.b	0
fast_msg:
	dc.b	"FASTFORMATTING"
	dc.b	0
normal_msg:
	dc.b	"NORMAL DISK COMMAND"
	dc.b	0
exit_msg:
	dc.b	13,"BYE!",13,0

namebuf:
	ds.b	32
namebuflen	EQU	.-namebuf


;**************************************************************************
;*
;* linkage
;*
;******
; general disk support
	INCLUDE	"diskutil.asm"

; the actual fast format routine
	INCLUDE	"fastformat.asm"

; eof
